<?php
defined('_JEXEC') or die();
/**
 *
 * @package    VirtueMart
 * @subpackage Plugins  - Fields
 * @author Reinhold Kainhofer, Open Tools
 * @link http://www.open-tools.net
 * @copyright Copyright (c) 2014 Reinhold Kainhofer. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.txt
 * VirtueMart is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 */
 
defined('DS') or define('DS', DIRECTORY_SEPARATOR);
if (!class_exists( 'VmConfig' )) 
    require(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_virtuemart'.DS.'helpers'.DS.'config.php');
VmConfig::loadConfig();

class JFormFieldVmOrdernumberReplacements extends JFormField {
    var $_name = 'vmOrdernumberReplacements';
    static $pluginpath = '/plugins/vmshopper/ordernumber/ordernumber/';

    
    protected $countertype;

    // VM2 on J2 works, VM3 on J3 works out of the box, but
    // VM3 on J2 does NOT work by simply calling vmJsApi::jQuery, because
    // the JS is never added to the page header, so we have to add this manually
    protected function loadjQuery() {
        vmJsApi::jQuery();
        // TODO: jquery::ui available only in J3:
        JHtml::_('jquery.ui', array('core', 'sortable'));
        // If we are on Joomla 2.5 and VM 3, manually add the script declarations 
        // cached in vmJsApi to the document header:
        if (version_compare(JVERSION, '3.0', 'lt') && defined('VM_VERSION') && VM_VERSION>=3) {
            $document = JFactory::getDocument();
            $scripts = vmJsApi::getJScripts();
            foreach ($scripts as $name => $jsToAdd) {
                if($jsToAdd['written']) continue;
                $file = $jsToAdd['script'] ? $jsToAdd['script'] : $name;

                if(strpos($file,'/')!==0){
                    $file = vmJsApi::setPath($file,false,'');
                } else if(strpos($file,'//')!==0){
                    $file = JURI::root(true).$file;
                }

                $ver = '';
                if(!empty($jsToAdd['ver'])) $ver = '?vmver='.$jsToAdd['ver'];
                $document->addScript( $file .$ver,"text/javascript",$jsToAdd['defer'],$jsToAdd['async'] );
                vmJsApi::removeJScript($name);
            }
        }
    }

    static function img_url($file) {
        return JURI::root(true) . self::$pluginpath . 'assets/images/' . $file;
    }
    static function css_url($file) {
        return JURI::root(true) . self::$pluginpath . 'assets/css/' . $file;
    }
    static function js_url($file) {
        return JURI::root(true) . self::$pluginpath . 'assets/js/' . $file;
    }
    static function __($string) {
		return JText::_($string);
    }
    
    protected function makeJSTranslationsAvailable() {
//         JText::script('PLG_ORDERNUMBER_JS_JSONERROR');
    }
    protected function getInput() {
    
        $html=array();
        $doc = JFactory::getDocument()->addStyleSheet(self::css_url('ordernumber.css'));
        $doc->addScript( self::js_url('ordernumber.js'));
        $this->makeJSTranslationsAvailable();
        $this->loadjQuery();
        
        
        $value = $this->value;
//         $html[] = "<pre> value: ".print_r($value,1)."</pre>";
//         $html[] = "<pre>Form Field: ".print_r($this,1)."</pre>";
        $variables = array();
        if (!is_array($value))
            $value = array();
        
        if (!empty($value)) {
            $keys = array_keys($value);
            foreach (array_keys($value[$keys[0]]) as $i) {
                $entry = array();
                foreach ($keys as $k) {
                    $entry[$k] = $value[$k][$i];
                }
                $variables[] = $entry;
            }
        }
        
        $id = $this->id;
        $name = $this->name;
        
        
//         $html[] = "<pre>Variables: ".print_r($variables,1)."</pre>";
        $html[] = '<table id="ordernumber_variables_template" style="display:none">';
        $html[] = $this->create_replacements_row_html($name, array(), 'disabled');
        $html[] = '</table>';
        
        $html[] = '<table id="ordernumber_variables" class="ordernumber_variables widefat wc_input_table sortable" cellspacing="0">';
        $columns = array(
            'variables_ifvar'    => self::__( 'If variable ...'),
            'variables_ifop'     => '',
            'variables_ifval'    => self::__( 'Value'),
            'variables_then'     => self::__( ''),
            'variables_thenvar'  => self::__( 'Set variable ...'),
            'variables_thenval'  => self::__( 'to value ...'),
            'sort'     => '',
            'variables_settings' => '',
        );
        $html[] = '	<thead>';
        $html[] = '		<tr class="ordernumber_variables_header">';
        foreach ( $columns as $key => $column ) {
        	$html[] = '<th class="' . $key . '">' . htmlspecialchars( $column ) . '</th>';
        }
        $html[] = '		</tr>';
        $html[] = '		<tr id="ordernumber-replacements-empty-row" class="oton-empty-row-notice ' . (empty($variables)?"":"rowhidden") . '">';
        $html[] = '			<td class="oton-empty-row-notice" colspan="8">';
        $html[] = '				<em>a' . self::__('No custom variables have been defined.') . '</em>';
        $html[] = '				<input type="hidden" name="' . $name . '" value="" ' . (empty($variables))?'':'disabled' . '>';
        $html[] = '			</td>';
        $html[] = '		</tr>';
        $html[] = '	</thead>';
        $html[] = '	<colgroup>';
        foreach ($columns as $key => $column) {
        	$html[] = '<col class="' . $key . '" />';
        }
        $html[] = '	</colgroup>';
        $html[] = '';
        $html[] = '	<tbody>';
        foreach ($variables as $var) {
        	$html[] = $this->create_replacements_row_html($name, $var);
        }
        $html[] = '	</tbody>';
        $html[] = '	<tfoot>';
        $html[] = '		<tr class="addreplacement_row">';
        $html[] = '			<td colspan=8 class="variable_add">';
        $html[] = '				<div class="ordernumber-variables-addbtn ordernumber-btn" onClick="ordernumberVariablesAddRow(\'ordernumber_variables_template\', \'ordernumber_variables\')">';
        $html[] = '					<div class="ordernumber-ajax-loading"><img src="' . self::img_url( 'icon-16-new.png' ) . '" class="ordernumber-counter-addbtn" /></div>';
        $html[] = self::__('Add new custom variable');
        $html[] = '				</div>';
        $html[] = '			</td>';
        $html[] = '		</tr>';
        $html[] = '	</tfoot>';
        $html[] = '</table>';
        return implode("\n", $html);
    }
    
    protected function create_replacements_row_html($name, $values = array(), $disabled = '') {
        $operator = (isset($values['conditionop'])?$values['conditionop']:'');
        $operators = array(
            'equals'       => '=', 
            'contains'     => self::__('contains'), 
            'smaller'      => '<',
            'smallerequal' => '<=',
            'larger'       => '>',
            'largerequal'  => '>=', 
            'startswith'   => self::__('starts with'),
            'endswith'     => self::__('ends with'),
        );
        $html  = '
        <tr>
        	<td class="variables_ifvar"><input name="' . $name . '[conditionvar][]" value="' . (isset($values['conditionvar'])?$values['conditionvar']:'') . '" ' . $disabled . '/></td>
        	<td class="variables_ifop"      ><select name="' . $name . '[conditionop][]" ' . $disabled . ' style="width: 100px">';
        foreach ($operators as $op => $opname) {
        	$html .= '		<option value="' . $op . '" ' . (($op === $operator)?'selected':'') . '>' . htmlspecialchars($opname) . '</option>';
        }
        $html .= '</select></td>
        	<td class="variables_ifval"   ><input name="' . $name . '[conditionval][]" value="' . (isset($values['conditionval'])?$values['conditionval']:'') . '" ' . $disabled . '/></td>
        	<td class="variables_then">=></td>
        	<td class="variables_thenvar"><input name="' . $name . '[newvar][]"       value="' . (isset($values['newvar'])?$values['newvar']:'') .       '" ' . $disabled . '/></td>
        	<td class="variables_thenval"><input name="' . $name . '[newval][]"       value="' . (isset($values['newval'])?$values['newval']:'') .       '" ' . $disabled . '/></td>
        	<td class="sort"></td>
        	<td class="variables_settings"><img src="' . self::img_url( 'icon-16-delete.png' ) . '" class="ordernumber-replacement-deletebtn ordernumber-btn"></td>
        </tr>';
        return $html;
    }

    
}